***************
Developer Guide
***************

The following sections will help you understand and change
how Nengo builds and simulates brain models.

.. toctree::
   :maxdepth: 2

   dev_introduction
   dev_api
   nef_minimal
   workflow
   releasing
